@@ -268,10 +268,11 @@ queue_changed (GnomeBG *bg)
 		g_source_remove (bg->changed_id);
 	}
 
-	bg->changed_id = g_idle_add_full (G_PRIORITY_LOW,
-					  (GSourceFunc)do_changed,
-					  bg,
-					  NULL);
+	bg->changed_id = g_timeout_add_full (G_PRIORITY_LOW,
+					     100,
+					     (GSourceFunc)do_changed,
+					     bg,
+					     NULL);
 }
 
 void
@@ -290,7 +291,7 @@ gnome_bg_load_from_preferences (GnomeBG     *bg,
 	/* Filename */
 	filename = NULL;
 	tmp = gconf_client_get_string (client, BG_KEY_PICTURE_FILENAME, NULL);
-	if (tmp != NULL) {
+	if (tmp != NULL && *tmp != '\0') {
 		if (g_utf8_validate (tmp, -1, NULL) &&
 		    g_file_test (tmp, G_FILE_TEST_EXISTS)) {
 			filename = g_strdup (tmp);
